summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneylineedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneylineedit.h')
-rw-r--r--kmymoney2/widgets/kmymoneylineedit.h37
1 files changed, 19 insertions, 18 deletions
diff --git a/kmymoney2/widgets/kmymoneylineedit.h b/kmymoney2/widgets/kmymoneylineedit.h
index 2351082..f92bd08 100644
--- a/kmymoney2/widgets/kmymoneylineedit.h
+++ b/kmymoney2/widgets/kmymoneylineedit.h
@@ -45,16 +45,17 @@
class kMyMoneyLineEdit : public KLineEdit
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
- * @param w pointer to parent
+ * @param w pointer to tqparent
* @param name pointer to name of object
* @param forceMonetaryDecimalSymbol if @a true, the numeric keypad comma key will have a fixed
* value and does not follow the keyboard layout (default: @p false)
* @param alignment Controls the alignment of the text. Default is Qt::AlignLeft | Qt::AlignVCenter.
* See Qt::AlignmentFlags for other possible values.
*/
- kMyMoneyLineEdit(QWidget *w = 0, const char* name = 0, bool forceMonetaryDecimalSymbol = false, int alignment = (AlignLeft | AlignVCenter));
+ kMyMoneyLineEdit(TQWidget *w = 0, const char* name = 0, bool forceMonetaryDecimalSymbol = false, int tqalignment = (AlignLeft | AlignVCenter));
~kMyMoneyLineEdit();
/**
@@ -66,50 +67,50 @@ public:
/**
* This method is used to turn on/off the hint display
*/
- void setHint(const QString& hint) { m_hint = hint; };
+ void setHint(const TQString& hint) { m_hint = hint; };
public slots:
- void loadText(const QString& text);
+ void loadText(const TQString& text);
signals:
/**
* This signal is emitted when the focus leaves the object and the text
* has been changed. The new text is passed as @a str.
*/
- void lineChanged(const QString& str);
+ void lineChanged(const TQString& str);
protected:
- void focusOutEvent(QFocusEvent *ev);
+ void focusOutEvent(TQFocusEvent *ev);
/** reimplemented to support the hint display */
- void drawContents( QPainter *);
+ void drawContents( TQPainter *);
/**
* Overridden so that the period key on the numeric keypad always sends
* out the currently selected monetary decimal symbol instead of the
* key defined by the keymap.
*
- * Example: If you have set the keymap (keyboard layout) as English, then
+ * Example: If you have set the keymap (keyboard tqlayout) as English, then
* the numeric keypad will send a period but if you have set the keymap to
* be German, the same key will send a comma.
*
* @param ev pointer to current QKeyEvent
*/
- void keyPressEvent(QKeyEvent* ev);
+ void keyPressEvent(TQKeyEvent* ev);
/**
* Overridden so that the period key on the numeric keypad always sends
* out the currently selected monetary decimal symbol instead of the
* key defined by the keymap.
*
- * Example: If you have set the keymap (keyboard layout) as English, then
+ * Example: If you have set the keymap (keyboard tqlayout) as English, then
* the numeric keypad will send a period but if you have set the keymap to
* be German, the same key will send a comma.
*
* @param ev pointer to current QKeyEvent
*/
- void keyReleaseEvent(QKeyEvent* ev);
+ void keyReleaseEvent(TQKeyEvent* ev);
private:
/**
@@ -118,12 +119,12 @@ private:
* and as comparison during focusOutEvent() to emit the lineChanged
* signal if the current text is different.
*/
- QString m_text;
+ TQString m_text;
/**
* This member tells what to display as hint as long as the field is empty
*/
- QString m_hint;
+ TQString m_hint;
/**
* This member keeps the status if overriding the numeric keypad comma key
@@ -45,16 +45,17 @@
* @param name pointer to name of object
* @param forceMonetaryDecimalSymbol if @a true, the numeric keypad comma key will have a fixed
- * value and does not follow the keyboard layout (default: @p false)
- * @param alignment Controls the alignment of the text. Default is Qt::AlignLeft | Qt::AlignVCenter.
- * See Qt::AlignmentFlags for other possible values.
+ * value and does not follow the keyboard tqlayout (default: @p false)
+ * @param tqalignment Controls the tqalignment of the text. Default is TQt::AlignLeft | TQt::AlignVCenter.
+ * See TQt::AlignmentFlags for other possible values.
*/
@@ -66,50 +67,50 @@ public:
* be German, the same key will send a comma.
*
- * @param ev pointer to current QKeyEvent
+ * @param ev pointer to current TQKeyEvent
*/
@@ -66,50 +67,50 @@ public:
* be German, the same key will send a comma.
*
- * @param ev pointer to current QKeyEvent
+ * @param ev pointer to current TQKeyEvent
*/